@@ -34,6 +34,7 @@ impl Reader for FileReader {
           buffer: Buffer {
             size: None,
             position: 0,
+            max_end_position: None,
             buffer: vec![]
           }
         },
@@ -52,6 +53,14 @@ impl Reader for FileReader {
     self.buffer.size = cache_size;
   }
 
+  fn get_max_end_position(&self) -> Option<u64> {
+    self.buffer.max_end_position
+  }
+
+  fn set_max_end_position(&mut self, max_end_position: Option<u64>) {
+    self.buffer.max_end_position = max_end_position;
+  }
+
   fn get_size(&mut self) -> Result<u64, String> {
     let metadata = try!(fs::metadata(self.filename.clone()).map_err(|e| e.to_string()));
     Ok(metadata.len())
